@@ -85,5 +85,14 @@ PASSWORD_HASHERS = ['django.contrib.auth.hashers.MD5PasswordHasher']
 
 DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
 
-WAGTAIL_SITE_NAME = 'wagtail-cblocks test'
+# Wagtail settings
+
 BASE_URL = 'http://testserver'
+
+WAGTAIL_SITE_NAME = 'wagtail-cblocks test'
+
+WAGTAILSEARCH_BACKENDS = {
+    'default': {
+        'BACKEND': 'wagtail.search.backends.database',
+    }
+}
